@@ -6,13 +6,14 @@ from acido.azure_utils.BlobManager import BlobManager
 from acido.azure_utils.InstanceManager import *
 from acido.azure_utils.ManagedIdentity import ManagedAuthentication
 from msrestazure.azure_exceptions import CloudError
-from acido.utils.functions import chunks, exec_command, jpath, expanduser
+from acido.utils.functions import chunks, jpath, expanduser
 from huepy import good, bad, info, bold, green, red, orange
 from multiprocessing.pool import ThreadPool
 import code
 import re
 import os
 import sys
+import time
 from os import mkdir, getenv
 from acido.utils.decoration import BANNER, __version__
 
@@ -103,14 +104,15 @@ class Acido(object):
             self._load_config()
         except FileNotFoundError:
             self.setup()
-
-        az_identity_list = subprocess.check_output(f'az identity create --resource-group {self.rg} --name acido', shell=True)
-        try:
-            az_identity_list = json.loads(az_identity_list)
-            self.user_assigned = az_identity_list
-        except Exception as e:
-            print(bad('FATAL ERROR: Could not find the user assigned identity "acido".'))
-            sys.exit()
+        
+        if not self.is_cloud():
+            az_identity_list = subprocess.check_output(f'az identity create --resource-group {self.rg} --name acido', shell=True)
+            try:
+                az_identity_list = json.loads(az_identity_list)
+                self.user_assigned = az_identity_list
+            except Exception as e:
+                print(bad('FATAL ERROR: Could not find the user assigned identity "acido".'))
+                sys.exit()
 
         im = InstanceManager(self.rg, login, self.user_assigned)
         im.login_image_registry(
@@ -259,6 +261,68 @@ class Acido(object):
                 print(good(f'Input written to: {filename}'))
         return input_file
 
+    def exec_command(self, cg, cont, command, max_retries):
+        env = os.environ.copy()
+        env["PATH"] = "/usr/sbin:/sbin:" + env["PATH"]
+        subprocess.Popen(["tmux", "new-session", "-d", "-s", cont], env=env)
+        time.sleep(1)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont,
+                        f"az container exec -g {self.rg} -n {cg} --container-name {cont} --exec-command /bin/bash", "Enter",
+                        ], env=env)
+        time.sleep(15)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, f"nohup python3 -m acido.cli -sh '{command}' > temp &", "Enter"], env=env)
+        time.sleep(2)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+
+        output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
+
+        time.sleep(4)
+
+        retries = 0
+        failed = False
+
+        while 'Done' not in output:
+
+            retries += 1
+
+            if retries > max_retries:
+                output = ''
+                failed = True
+                break
+
+            subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+            time.sleep(5)
+            output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
+
+            if 'Done' in output:
+                break
+
+        if not failed:
+            subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+            time.sleep(2)
+            subprocess.Popen(["tmux", "send-keys", "-t", cont, "(cat temp) > output", "Enter", "Enter"], env=env)
+            time.sleep(5)
+            subprocess.Popen(["tmux", "send-keys", "-t", cont, "cat output", "Enter"], env=env)
+            time.sleep(10)
+            subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+            time.sleep(2)
+
+            try:
+                output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env)
+                output = output.decode().split('Executed command: ')[1].strip()
+                print(output)
+            except Exception as e:
+                output = None
+                print(bad(f'Error capturing output from: {bold(cont)}'))
+
+
+        # Kill shell
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "(rm temp && rm output && exit)", "Enter"], env=env)
+        time.sleep(1)
+        # Kill tmux window
+        subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env)
+
+        return cont, output
 
     def exec(self, command, max_retries=60, input_cmd: str = None):
         global global_responses
@@ -273,9 +337,9 @@ class Acido(object):
             if cg in self.selected_instances:
                 for cont in containers:
                     executed = True
-                    result = pool.apply_async(exec_command, 
+                    result = pool.apply_async(self.exec_command, 
                                              (self.rg, cg, cont, command, max_retries), 
-                                              callback=instances_outputs)
+                                              callback=build_output)
                     results.append(result)
         
         if not executed:
